@@ -120,7 +120,9 @@ expr' e =
     "mtable" -> mkE <$> table e
     "maction" -> mkE <$> action e
     "semantics" -> mkE <$> semantics e
-    _ -> return $ mkE empty
+    "maligngroup" -> return $ mkE empty
+    "malignmark" -> return $ mkE empty
+    _ -> throwError $ "Unexpected element " ++ err e
   where
     mkE :: Exp -> [IR Exp]
     mkE = (:[]) . E
@@ -560,7 +562,7 @@ nargs :: Int -> [a] -> Bool
 nargs n xs = length xs == n
 
 err :: Element -> String
-err e = name e ++ " line: " ++ (show $ elLine e) ++ (show e)
+err e = name e ++ maybe "" (\x -> " line " ++ show x) (elLine e)
 
 findAttrQ :: String -> Element -> MML (Maybe String)
 findAttrQ s e = do
