@@ -35,11 +35,12 @@ module Text.TeXMath.Readers.OMML (readOMML) where
 import Text.XML.Light
 import Data.Maybe (isJust, mapMaybe, fromMaybe)
 import Data.List (intercalate)
-import Data.Char (isDigit)
+import Data.Char (isDigit, readLitChar)
 import Text.TeXMath.Types
 import Text.TeXMath.Shared (fixTree, getSpaceWidth, getOperator)
 import Text.TeXMath.Unicode.ToTeX (getSymbolType)
 import Control.Applicative ((<$>))
+import Text.TeXMath.Unicode.Fonts (getUnicode, stringToFont)
 
 readOMML :: String -> Either String [Exp]
 readOMML s | Just e <- parseXMLDoc s =
@@ -163,6 +164,7 @@ elemToOMathRunElem element
     || isElem "w" "delText" element = Just $ TextRun $ strContent element
   | isElem "w" "br" element = Just LnBrk
   | isElem "w" "tab" element = Just Tab
+  | isElem "w" "sym" element = Just $ TextRun $ getSymChar element
   | otherwise = Nothing
 
 elemToOMathRunElems :: Element -> Maybe [OMathRunElem]
@@ -230,7 +232,7 @@ elemToExps' element | isElem "m" "acc" element = do
             Just . head
       chr' = case chr of
         Just c -> c
-        Nothing -> '^'       -- default to hat.
+        Nothing -> '\x302'       -- default to wide hat.
   baseExp <- filterChildName (hasElemName "m" "e") element >>=
              elemToBase
   return $ [EOver False baseExp (ESymbol Accent [chr'])]
@@ -241,8 +243,8 @@ elemToExps' element | isElem "m" "bar" element = do
   baseExp <- filterChildName (hasElemName "m" "e") element >>=
              elemToBase
   case pos of
-    "top" -> Just [EOver False baseExp (ESymbol Accent "\175")]
-    "bot" -> Just [EUnder False baseExp (ESymbol Accent "\818")]
+    "top" -> Just [EOver False baseExp (ESymbol TOver "\773")]
+    "bot" -> Just [EUnder False baseExp (ESymbol TUnder "\818")]
     _     -> Nothing
 elemToExps' element | isElem "m" "box" element = do
   baseExp <- filterChildName (hasElemName "m" "e") element >>=
@@ -313,13 +315,13 @@ elemToExps' element | isElem "m" "groupChr" element = do
             Just (c:_) -> c
             _           -> '\65079'   -- default to overbrace
       in
-       return [EOver False baseExp (ESymbol Accent [chr'])]
+       return [EOver False baseExp (ESymbol TOver [chr'])]
     Just "bot" ->
       let chr' = case chr of
             Just (c:_) -> c
             _           -> '\65080'   -- default to underbrace
       in
-       return [EUnder False baseExp (ESymbol Accent [chr'])]
+       return [EUnder False baseExp (ESymbol TUnder [chr'])]
     _          -> Nothing
 elemToExps' element | isElem "m" "limLow" element = do
   baseExp <- filterChildName (hasElemName "m" "e") element
@@ -467,3 +469,17 @@ expToString (EText _ s) = s
 expToString (EGrouped exps) = concatMap expToString exps
 expToString (EStyled _ exps) = concatMap expToString exps
 expToString _ = ""
+
+-- The char attribute is a hex string
+getSymChar :: Element -> String
+getSymChar element
+  | Just s <- lowerFromPrivate <$> getCodepoint
+  , Just font <- getFont =
+  let [(char, _)] = readLitChar ("\\x" ++ s) in
+    maybe "" (:[]) $ getUnicode font char
+  where
+    getCodepoint = findAttrBy (hasElemName "w" "char") element
+    getFont = stringToFont =<< findAttrBy (hasElemName "w" "font") element
+    lowerFromPrivate ('F':xs) = '0':xs
+    lowerFromPrivate xs = xs
+getSymChar _ = ""
